amplify_auth_cognito library
Classes
- AmplifyAuthCognito
- The AWS Cognito implementation of the Amplify Auth category.
- AuthCodeDeliveryDetails
- AuthDevice
- Common interface for devices tracked by an authentication provider.
- AuthNextSignInStep
- AuthNextSignUpStep
- AuthNextStep
- AuthNextUpdateAttributeStep
- This wraps all the details around the next step in the user attribute update process.
- AuthProvider
- AuthSession
- AuthSessionOptions
- AuthSessionRequest
- AuthUser
- AuthUserAttribute
- AuthUserOptions
- AuthUserRequest
- AWSCognitoUserPoolTokens
- AWSCredentials
- CognitoAuthSession
- CognitoConfirmResetPasswordOptions
- Cognito extension of ConfirmResetPasswordOptions to add the platform specific fields.
- CognitoConfirmSignInOptions
- CognitoConfirmSignUpOptions
- CognitoDevice
- A device tracked by AWS Cognito.
- CognitoResendSignUpCodeOptions
- Cognito extension of ResendSignUpCodeOptions to add the platform specific fields
- CognitoResendSignUpCodeResult
- CognitoResendUserAttributeConfirmationCodeOptions
- Cognito extension of ResendUserAttributeConfirmationCodeOptions to add the platform specific fields
- CognitoResetPasswordOptions
- Cognito extension of ResetPasswordOptions to add the platform specific fields.
- CognitoResetPasswordResult
- CognitoSessionOptions
- CognitoSignInOptions
- CognitoSignInResult
- CognitoSignInWithWebUIOptions
- CognitoSignUpOptions
- CognitoSignUpResult
- CognitoUpdatePasswordOptions
- Cognito extension of update password options to add the platform specific fields
- CognitoUpdateUserAttributeOptions
- Cognito extension of UpdateUserAttributeOptions to add the platform specific fields
- CognitoUpdateUserAttributesOptions
- Cognito extension of UpdateUserAttributesOptions to add the platform specific fields
- CognitoUserAttributeKey
-
User attributes available for configuring via
Amplify.Auth.signUp, or updating viaAmplify.Auth.updateUserAttributeandAmplify.Auth.updateUserAttributes. - ConfirmResetPasswordOptions
- The shared confirm reset password options among all Auth plugins.
- ConfirmResetPasswordRequest
- Encapsulates parameters for a confirm reset password request.
- ConfirmSignInOptions
- ConfirmSignInRequest
- ConfirmSignUpOptions
- ConfirmSignUpRequest
- ConfirmUserAttributeRequest
- Encapsulates parameters for a request to confirm a user attribute update.
- ConfirmUserAttributeResult
- Wraps the result of a confirm user attribute operation.
- FetchUserAttributesOptions
- The shared fetch user attributes options among all Auth plugins.
- FetchUserAttributesRequest
- Encapsulates parameters for a fetch user attributes operation
- ResendSignUpCodeOptions
- The shared resend sign up code options among all Auth plugins.
- ResendSignUpCodeRequest
- Encapsulates parameters for a resend sign up code request.
- ResendSignUpCodeResult
- ResendUserAttributeConfirmationCodeOptions
- The shared resend user attribute confirmation code options among all Auth plugins.
- ResendUserAttributeConfirmationCodeRequest
- Encapsulates parameters for a request to resend a user attribute confirmation code.
- ResendUserAttributeConfirmationCodeResult
- Wraps the result of a resend user confirmation code operation.
- ResetPasswordOptions
- The shared reset password options among all Auth plugins.
- ResetPasswordRequest
- Encapsulates parameters for a reset password request.
- ResetPasswordResult
- The result of a password reset request.
- ResetPasswordStep
- The next step required for resetting a user's password.
- SignInOptions
- SignInRequest
- SignInResult
- SignInWithWebUIOptions
- SignInWithWebUIRequest
- SignOutOptions
- The shared sign out options among all Auth plugins.
- SignOutRequest
- Encapsulates parameters for a sign out request
- SignOutResult
- SignUpOptions
- SignUpRequest
- SignUpResult
- UpdatePasswordOptions
- The shared update password options among all Auth plugins.
- UpdatePasswordRequest
- Encapsulates parameters for an update password request
- UpdatePasswordResult
- The result of an update password request.
- UpdateUserAttributeOptions
- The shared update user attribute options among all Auth plugins.
- UpdateUserAttributeRequest
- Encapsulates parameters for a update user attribute operation.
- UpdateUserAttributeResult
- Wraps the result of an update user attribute operation.
- UpdateUserAttributesOptions
- The shared update user attributes options among all Auth plugins.
- UpdateUserAttributesRequest
- Encapsulates parameters for a update user attributes operation.
- UserAttributeKey
- A user attribute identifier.
Extensions
- AuthDeviceX on AuthDevice
- Helper functions for AuthDevice.
Exceptions / Errors
- AliasExistsException
- Exception thrown when attempts are made to confirm the account with an email or phone number that has already been supplied as an alias from a different account. This exception indicates an account with this email or phone already exists.
- AuthException
- The base class for Auth category exceptions.
- CodeDeliveryFailureException
- Exception thrown when a verification code fails to deliver successfully.
- CodeExpiredException
- Exception thrown when a verification code provided to the requested service is expired.
- CodeMismatchException
- Exception thrown when a verification code provided to the requested service doesn't match what the service was expecting.
- DeviceNotTrackedException
- Exception thrown when a request is made for a device which is either not currently tracked or previously forgotten.
- FailedAttemptsLimitExceededException
- Exception thrown when too many failed attempts for a given action has been made, such as sign-in.
- InternalErrorException
- Exception thrown when the requested service encounters an internal error.
- InvalidAccountTypeException
- Exception thrown when the configuration of the signed in account does not support the requested operation.
- InvalidParameterException
- Exception thrown when the requested service encounters an invalid parameter.
- InvalidPasswordException
- Exception thrown when the requested service encounters an invalid password.
- InvalidStateException
- Exception thrown when the requested operation is not valid in the current Amplity Auth state.
- InvalidUserPoolConfigurationException
- Exception thrown when a user pool configuration provided to the requested service is invalid.
- LambdaException
- Exception thrown when an error from the AWS Lambda service is encountered.
- LimitExceededException
- Exception thrown when the limit for the requested service resource is exceeded.
- MFAMethodNotFoundException
- Exception thrown when the requested service cannot find a multi-factor authentication (MFA) method
- NotAuthorizedException
- Exception thrown when a user isn't authorized to access the requested resource.
- PasswordResetRequiredException
- Exception thrown when the requested operation requires a password reset.
- ResourceNotFoundException
- Exception thrown when the requested resource doesn't exist.
- SessionExpiredException
- Exception thrown when the current session is expired.
- Exception thrown when valid credentials could not be obtained due to the device being offline.
- Exception thrown when valid credentials could not be obtained due to the an error from the requested service.
- SignedOutException
- Exception thrown when the requested operation can't be performed due to the user being signed out.
- SoftwareTokenMFANotFoundException
- Exception thrown when the software token time-based one-time password (TOTP) multi-factor authentication (MFA) isn't activated for the user pool.
- TooManyFailedAttemptsException
- Exception thrown when too many failed attempts have been made for a given action, such as sign-in.
- TooManyRequestsException
- Exception thrown when a request is being made too frequently and is more than what the requested service can handle.
- UnknownException
- Exception thrown when an unknown error from an underlying SDK or service is encountered.
- UserCancelledException
- Exception thrown when a requested operation could not be completed because it was cancelled by the user.
- UsernameExistsException
- Exception thrown when the requested service encounters a user name that already exists in the user pool.
- UserNotConfirmedException
- Exception thrown when the requested operation can't be performed because the user hasn't been confirmed successfully with the requested service.
- UserNotFoundException
- Exception thrown when the requested operation can't be performed because the user can't be found by the requested service.